@@ -10,7 +10,7 @@ from .const import LogOperate
 __all__ = 'NAME', 'Settings', 'settings',
 
 NAME = 'PXD_ACTIONS_TRACKER'
-cached_import = lru_cache(import_string)
+cached_import = lru_cache()(import_string)
 
 
 @s(NAME)
